@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -25,10 +25,15 @@ class JavaScriptEvent;
 
 struct NoClass
 {
-  NoClass() { }
+#ifndef WT_TARGET_JAVA
+  constexpr
+#endif // WT_TARGET_JAVA
+    NoClass() { }
   NoClass(const JavaScriptEvent&) { }
 
-  static NoClass none;
+#ifdef WT_TARGET_JAVA
+  static const NoClass none;
+#endif // WT_TARGET_JAVA
 };
 
 #ifdef WT_TARGET_JAVA
@@ -112,9 +117,6 @@ public:
    */
   virtual bool isConnected() const = 0;
 
-  void setBlocked(bool block);
-  bool isBlocked() const { return blocked_; }
-
   /*! \brief Connects to a slot.
    *
    * Every signal can be connected to a slot which does not take any
@@ -136,8 +138,6 @@ protected:
 
 private:
   SignalBase(const SignalBase& other);
-
-  bool blocked_;
 };
 
 /*
@@ -501,16 +501,7 @@ protected:
 
   void prepareDestruct();
   void exposeSignal();
-  // If checkWasStubbed is true, processLearnedStateless will
-  // skip all slots belonging to widgets that were stubbed.
-  // It should only be set to true for events sent before the
-  // widgets were unstubbed.
-  void processLearnedStateless(bool checkWasStubbed) const;
-  // processStubbedStateless will only execute the slots
-  // belonging to widgets that were stubbed.
-  // It should only be executed for events sent before the
-  // widgets were unstubbed.
-  void processStubbedStateless() const;
+  void processLearnedStateless() const;
   void processNonLearnedStateless() const;
   virtual int argumentCount() const = 0;
 
@@ -659,7 +650,7 @@ public:
    * This will cause all connected slots to be triggered, with the given
    * argument.
    */
-  void emit(E e = NoClass::none) const;
+  void emit(E e = NoClass()) const;
 
   /*! \brief Emits the signal.
    *
@@ -898,11 +889,7 @@ EventSignal<E>::connect(WObject *target, WObject::Method method)
 template <typename E>
 void EventSignal<E>::emit(E e) const
 {
-  if (isBlocked())
-    return;
-
-  processLearnedStateless(false);
-
+  processLearnedStateless();
   processNonLearnedStateless();
 
   dynamic_.emit(e);
